import argparse


def edit_parser():
    parser = argparse.ArgumentParser(
        description='Open an interactive python session where AMF tables can be edited, visualized and compared. '
                    'Tables will be available in a dictionary called \'amf\' with keys matching the file names.')
    parser.add_argument('filenames', type=str, help='paths to files or directories containing AMF tables', nargs='+')
    parser.add_argument('-p', action='store_true',
                        help='set this to open a standard python session instead of the default ipython session')
    return parser


if __name__ == '__main__':
    import subprocess
    import skamf
    from os import getcwd
    from os.path import join, dirname

    parser = edit_parser()

    args = vars(parser.parse_args())
    filenames = [join(getcwd(), name) for name in args['filenames']]

    editfile = join(dirname(skamf.__file__), '_edit.py')
    if not args['p']:
        subprocess.run(['ipython', '-i', editfile] + filenames)
    else:
        subprocess.run(['python', '-i', editfile] + filenames)
