import numpy as np
import re
import xarray as xr


def parse_response(response, varname, default, mandatory=False, type=float):
    a = re.split(r'append', response)
    if len(a) > 1:
        return np.append(
            parse_response(a[0], varname, default, mandatory, type),
            parse_response(' '.join(a[1:]), varname, default, mandatory, type)
        )
    response = re.split(r'[,\s]+', response.strip())
    if response[0] == '':
        if default is None:
            raise ValueError(f'no default for {varname}.')
        else:
            return default
    elif response[0] == 'omit':
        if mandatory:
            raise ValueError(f'{varname} cannot be omitted.')
        print(f'Omitting {varname}.')
        return None
    elif response[0] == 'exit':
        print('Exiting.')
        exit(0)
    elif response[0] == 'linspace':
        if len(response) == 4:
            start = float(response[1])
            end = float(response[2])
            num = int(response[3])
            return np.linspace(start, end, num)
        else:
            raise ValueError('linspace requires 3 arguments')
    elif response[0] == 'arange':
        if len(response) == 4:
            start = float(response[1])
            end = float(response[2])
            step = float(response[3])
            return np.arange(start, end, step)
        else:
            print('arange requires 3 arguments')
    else:
        return np.array([type(v) for v in response])


def get_response(varname, prompt, default, mandatory=False, type=float):
    while 1:
        try:
            inp = input(f"{prompt}:\n{varname} = ")
            return parse_response(inp, varname, default, mandatory, type)
        except SystemExit:
            exit(0)
        except ValueError as err:
            print(f'Invalid response: {err}')
        except Exception:
            print('Invalid response.')


def parse_option_names(table: xr.Dataset, var_name: str) -> dict:
    option_str = table[var_name].attrs.get('sasktran_option', '')
    regex = re.compile(r'(\w+):\s?(\w+)')
    groups = regex.findall(option_str)
    option_names = {g[0]: g[1] for g in groups}
    return option_names
